@@ -1,7 +1,5 @@
 import functools
 
-import aiobtclientapi
-
 from . import constants, trackers, utils
 
 defaults = {
@@ -25,10 +23,16 @@ defaults = {
                 description=(
                     'List of directories to search for a *.torrent file '
                     'to get piece hashes from instead of generating the '
-                    'pieces hashes from file contents.\n'
+                    'pieces hashes from file contents.'
                 ),
             ),
         },
+        'screenshots': {
+            'optimize': utils.configfiles.config_value(
+                value=utils.types.Choice('default', options=utils.image.optimization_levels),
+                description='Whether to optimize screenshot file sizes',
+            ),
+        },
     },
 
     'trackers': {
@@ -42,20 +46,12 @@ defaults = {
     },
 
     'clients': {
-        client.name: {
-            'url': client.URL.default,
-            'username': '',
-            'password': '',
-            'check_after_add': utils.types.Bool('no'),
-        }
-        for client in aiobtclientapi.api_classes()
+        name: utils.btclient.client_defaults(name)
+        for name in utils.btclient.client_names()
     },
 }
 """Defaults for configuration options"""
 
-# Transmission cannot add torrent without verifying it
-defaults['clients']['transmission']['check_after_add'] = utils.types.Bool('yes')
-
 
 @functools.lru_cache(maxsize=None)
 def option_paths():
