@@ -103,6 +103,10 @@ class ImageResizeError(UpsiesError):
     """Image resizing failed"""
 
 
+class ImageOptimizeError(UpsiesError):
+    """Image optimization failed"""
+
+
 class TorrentError(UpsiesError):
     """Torrent file creation failed"""
 
