@@ -408,10 +408,23 @@ class JobBase(abc.ABC):
         This method does not block.
         """
         if not self.is_finished:
-            for task in self._tasks:
-                if not task.done():
-                    _log.debug('%s: Cancelling %r', self.name, task)
-                    task.cancel()
+
+            # Do not cancel tasks for now because it can print
+            # RuntimeWarning: coroutine ... was never awaited
+            #
+            # to stderr, for example when release-name command is already
+            # cached:
+            # $ upsies rn ...
+            # $ upsies rn ...  # Same command
+            #
+            # This may cause problems if long tasks are running when we call
+            # finish().
+
+            # for task in self._tasks:
+            #     if not task.done():
+            #         _log.debug('%s: Cancelling %r', self.name, task)
+            #         task.cancel()
+
             self._finished_event.set()
             self.signal.emit('finished', self)
             self._write_cache()
