@@ -354,6 +354,9 @@ class TextFieldJob(JobBase):
 
     @text.setter
     def text(self, text):
+        # Don't call validator here because it should be possible to set invalid
+        # texts and let the user fix it manually. We only validate when we
+        # commit to `text` (see send()).
         self._text = self._normalizer(str(text))
         self.signal.emit('text', self.text)
 
@@ -391,19 +394,8 @@ class TextFieldJob(JobBase):
         self._is_loading = bool(is_loading)
         self.signal.emit('is_loading', self.is_loading)
 
-    @property
-    def exit_code(self):
-        """
-        Always exit with ``0``
-
-        Instead of exiting with a non-zero exit code, the application should
-        :meth:`warn` the user about invalid values. This is done by providing a
-        `validator`.
-        """
-        if self.is_finished:
-            return 0
-
-    def initialize(self, *, name, label, text='', autofinish=False,
+    def initialize(self, *, name, label,
+                   text='', default=None, finish_on_success=False, nonfatal_exceptions=(),
                    validator=None, normalizer=None, obscured=False, read_only=False):
         """
         Set internal state
@@ -414,12 +406,19 @@ class TextFieldJob(JobBase):
             which will be called when the job is :meth:`executed
             <upsies.jobs.base.JobBase.execute>`. The return value is used as the
             initial text.
+        :param default: Text to use if `text` is `None`, returns `None` or
+            raises `nonfatal_exceptions`
+        :param finish_on_success: Whether to call :meth:`finish` after setting
+            :attr:`text` to `text`
 
-            .. warning:: If this is a :class:`callable` of any kind, all
-                         exceptions are raised fatally. All expected exceptions
-                         should be handled in the (asynchronous) function.
-        :param autofinish: Automatically :meth:`finish` after `text` is set
-            successfully
+            .. note:: :meth:`finish` is not called when :attr:`text` is set to
+                      `default`.
+        :param nonfatal_exceptions: Sequence of exception classes that may be
+            raised by `text` without crashing
+
+            Fatal exceptions are raised immediately while non-fatal exceptions
+            are passed to :meth:`warn`, and the user can fix the situation
+            manually.
         :param validator: Callable that gets text before job is finished. If
             `ValueError` is raised, it is displayed as a warning instead of
             finishing the job.
@@ -444,37 +443,142 @@ class TextFieldJob(JobBase):
         self.read_only = read_only
 
         if isinstance(text, str):
+            # Set text attribute immediately
             self.text = text
-        else:
-            # Get text from callable when job is executed
-            self._execute_arguments = (text, autofinish)
+
+        # Get text from callable when job is executed
+        self._execute_arguments = (text, default, finish_on_success, nonfatal_exceptions)
 
     def execute(self):
-        text, autofinish = getattr(self, '_execute_arguments', (None, None))
+        text, default, finish_on_success, nonfatal_exceptions = self._execute_arguments
 
         if inspect.isawaitable(text):
             self.attach_task(
-                self.fetch_text(coro=text, finish_on_success=autofinish),
+                self.fetch_text(
+                    coro=text,
+                    default=default,
+                    finish_on_success=finish_on_success,
+                    nonfatal_exceptions=nonfatal_exceptions,
+                )
             )
 
         elif inspect.iscoroutinefunction(text):
             self.attach_task(
-                self.fetch_text(coro=text(), finish_on_success=autofinish),
+                self.fetch_text(
+                    coro=text(),
+                    default=default,
+                    finish_on_success=finish_on_success,
+                    nonfatal_exceptions=nonfatal_exceptions,
+                )
             )
 
-        elif callable(text):
-            try:
-                self.text = text()
-            except BaseException as e:
-                self.exception(e)
-            else:
-                if autofinish:
-                    self.send(self.text)
+        else:
+            self.set_text(
+                text=text,
+                default=default,
+                finish_on_success=finish_on_success,
+                nonfatal_exceptions=nonfatal_exceptions,
+            )
 
-        elif text is not None:
+    def set_text(self, text, default=None, finish_on_success=False, nonfatal_exceptions=()):
+        """
+        Change :attr:`text` value
+
+        :param text: New text value
+
+            If this is callable, it must return the new :attr:`text` or `None`
+            to use `default`
+
+        :param default: Text to use if `text` is `None`, returns `None` or
+            raises `nonfatal_exceptions`
+
+        :param finish_on_success: Whether to call :meth:`finish` after setting
+            :attr:`text` to `text`
+
+            .. note:: :meth:`finish` is not called when :attr:`text` is set to
+                      `default`.
+
+        :param nonfatal_exceptions: Sequence of exception classes that may be
+            raised by `text` without crashing
+
+            Fatal exceptions are raised immediately while non-fatal exceptions
+            are passed to :meth:`warn`, and the user can fix the situation
+            manually.
+        """
+        self.is_loading = self.read_only = True
+        try:
+            if callable(text):
+                new_text = text()
+            elif text is not None:
+                new_text = str(text)
+            else:
+                new_text = None
+        except Exception as e:
+            self._set_text(default)
+            self._handle_exception(e, nonfatal=nonfatal_exceptions)
+        else:
+            self._set_text(new_text, default=default, finish=finish_on_success)
+        finally:
+            # Always re-enable text field after we're done messing with it
+            self.is_loading = self.read_only = False
+
+    async def fetch_text(self, coro, default=None, finish_on_success=False, nonfatal_exceptions=()):
+        """
+        Get :attr:`text` from coroutine
+
+        :param coro: Coroutine that returns the new :attr:`text` or `None` to
+            use `default`
+
+        :param default: Text to use if `text` is `None`, returns `None` or
+            raises `nonfatal_exceptions`
+
+        :param finish_on_success: Whether to call :meth:`finish` after setting
+            :attr:`text` to `coro` return value
+
+            .. note:: :meth:`finish` is not called when :attr:`text` is set to
+                      `default`.
+
+        :param nonfatal_exceptions: Sequence of exception classes that may be
+            raised by `coro` without crashing
+
+            Fatal exceptions are raised immediately while non-fatal exceptions
+            are passed to :meth:`warn`, and the user can fix the situation
+            manually.
+        """
+        self.is_loading = self.read_only = True
+        try:
+            new_text = await coro
+        except Exception as e:
+            _log.debug('CAUGHT EXCEPTION: %r', e)
+            self._set_text(default)
+            self._handle_exception(e, nonfatal=nonfatal_exceptions)
+        else:
+            self._set_text(new_text, default=default, finish=finish_on_success)
+        finally:
+            # Always re-enable text field after we're done messing with it
+            self.is_loading = self.read_only = False
+
+    def _set_text(self, text, default=None, finish=False):
+        # Fill in text
+        if text is not None:
             self.text = text
-            if autofinish:
-                self.send(self.text)
+            # Only finish if the intended text was set
+            if finish:
+                # We must call send() because it handles output caching, and it also
+                # finishes the job.
+                self.send(text)
+
+        elif default is not None:
+            self.text = default
+
+    def _handle_exception(self, exception, nonfatal=()):
+        # Display error and allow user to manually fix the situation
+        if isinstance(exception, nonfatal):
+            self.warn(exception)
+
+        # An exception we didn't expect
+        else:
+            raise exception
 
     def send(self, output):
         """
@@ -492,50 +596,3 @@ class TextFieldJob(JobBase):
         else:
             super().send(output)
             super().finish()
-
-    async def fetch_text(self, coro, default_text=None, finish_on_success=False, nonfatal_exceptions=()):
-        """
-        Get :attr:`text` from coroutine
-
-        :param coro: Coroutine that returns the new :attr:`text` or `None` to
-            use `default_text`
-        :param default_text: String to use if `coro` raises
-            `nonfatal_exceptions` or if `coro` returns `None`
-        :param finish_on_success: Whether to call :meth:`finish` after setting
-            :attr:`text` to `coro` return value
-        :param nonfatal_exceptions: Sequence of exception classes that may be
-            raised by `coro` without indicating failure
-
-            Non-fatal exceptions are passed to :meth:`warn` while fatal
-            exceptions are raised.
-        """
-        self.is_loading = self.read_only = True
-
-        try:
-            text = await coro
-
-        except Exception as e:
-            if default_text is not None:
-                self.text = default_text
-
-            if isinstance(e, nonfatal_exceptions):
-                # Display error and allow user to adjust the default text
-                self.warn(e)
-            else:
-                self.finish()
-                raise e
-
-        else:
-            if text is not None:
-                self.text = text
-            elif default_text is not None:
-                self.text = default_text
-
-            # We must call send() because it handles output caching, and it also
-            # finishes the job.
-            if finish_on_success and text is not None:
-                self.send(text)
-
-        finally:
-            # Always re-enable text field after we're done messing with it
-            self.is_loading = self.read_only = False
