@@ -34,7 +34,8 @@ class ScreenshotsJob(JobBase):
     label = 'Screenshots'
     cache_id = None
 
-    def initialize(self, *, content_path, exclude_files=(), timestamps=(), count=0, from_all_videos=False):
+    def initialize(self, *, content_path, exclude_files=(), timestamps=(), count=0,
+                   from_all_videos=False, optimize='default'):
         """
         Set internal state
 
@@ -55,6 +56,11 @@ class ScreenshotsJob(JobBase):
 
             See :func:`.video.find_videos` for more information.
 
+        :param optimize: `level` argument for :func:`~image.optimize`
+
+            If this is ``"default"``, missing optimization dependencies are
+            silently ignored.
+
         If `timestamps` and `count` are not given, screenshot positions are
         picked at even intervals. If `count` is larger than the number of
         `timestamps`, more timestamps are added.
@@ -66,7 +72,9 @@ class ScreenshotsJob(JobBase):
         self._timestamps = timestamps
         self._count = count
         self._from_all_videos = from_all_videos
+        self._optimize = optimize
         self._screenshots_process = None
+        self._optimize_process = None
         self._screenshots_by_file = collections.defaultdict(lambda: [])
         self.signal.add('screenshots_total', record=True)
 
@@ -76,8 +84,15 @@ class ScreenshotsJob(JobBase):
 
         The subprocess also picks video file(s) and timestamps.
         """
+        if self._optimize not in ('none', None):
+            self._execute_screenshots_process()
+            self._execute_optimize_process()
+        else:
+            self._execute_screenshots_process()
+
+    def _execute_screenshots_process(self):
         self._screenshots_process = daemon.DaemonProcess(
-            name=self.name,
+            name='_screenshots_process',
             target=_screenshots_process,
             kwargs={
                 'content_path': self._content_path,
@@ -90,15 +105,27 @@ class ScreenshotsJob(JobBase):
             },
             info_callback=self._handle_info,
             error_callback=self._handle_error,
-            finished_callback=self.finish,
         )
         self._screenshots_process.start()
 
-    def finish(self):
-        """Terminate screenshot creation subprocess and finish"""
-        if self._screenshots_process:
-            self._screenshots_process.stop()
-        super().finish()
+    def _execute_optimize_process(self):
+        self._optimize_process = daemon.DaemonProcess(
+            name='_optimize_process',
+            target=_optimize_process,
+            kwargs={
+                # Use default optimization level if None is provided
+                'level': self._optimize,
+                # Ignore missing dependecy if we do "default" optimization
+                'ignore_dependency_error': (
+                    True
+                    if self._optimize == 'default' else
+                    False
+                ),
+            },
+            info_callback=self._handle_info,
+            error_callback=self._handle_error,
+        )
+        self._optimize_process.start()
 
     def _handle_info(self, info):
         if not self.is_finished:
@@ -107,9 +134,27 @@ class ScreenshotsJob(JobBase):
                 self.signal.emit('screenshots_total', self._screenshots_total)
 
             if 'screenshot_path' in info:
-                self._screenshots_created += 1
                 self._screenshots_by_file[info['video_path']].append(info['screenshot_path'])
-                self.send(info['screenshot_path'])
+
+                if self._optimize_process:
+                    _log.debug('Optimizing %s: %.2f KiB',
+                               info['screenshot_path'],
+                               fs.file_size(info['screenshot_path']) / 1024)
+                    self._optimize_process.send(daemon.MsgType.info, info['screenshot_path'])
+
+                else:
+                    self._screenshots_created += 1
+                    self.send(info['screenshot_path'])
+
+            elif 'optimized_screenshot_path' in info:
+                _log.debug('Optimized %s: %.2f KiB',
+                           info['optimized_screenshot_path'],
+                           fs.file_size(info['optimized_screenshot_path']) / 1024)
+                self._screenshots_created += 1
+                self.send(info['optimized_screenshot_path'])
+
+            if self.screenshots_created == self.screenshots_total:
+                self.finish()
 
     def _handle_error(self, error):
         if isinstance(error, BaseException):
@@ -117,6 +162,14 @@ class ScreenshotsJob(JobBase):
         else:
             self.error(error)
 
+    def finish(self):
+        """Terminate screenshot creation subprocess and finish"""
+        if self._screenshots_process:
+            self._screenshots_process.stop()
+        if self._optimize_process:
+            self._optimize_process.stop()
+        super().finish()
+
     @property
     def exit_code(self):
         """`0` if all screenshots were made, `1` otherwise, `None` if unfinished"""
@@ -302,6 +355,41 @@ def _screenshots_process(output_queue, input_queue,
         pass
 
 
+def _optimize_process(output_queue, input_queue, *, level, ignore_dependency_error):
+    # Get as many queued screenshots as possible. Check if there's a termination
+    # sentinel before optimizing each screenshot to avoid processing all the
+    # screenshots before Ctrl-C takes effect.
+    msgs = []
+    while True:
+        new_msgs = _read_queue_until_empty(input_queue=input_queue)
+        msgs.extend(new_msgs)
+
+        if any(typ is daemon.MsgType.terminate for typ, msg_ in msgs):
+            break
+
+        elif msgs:
+            typ_, screenshot_file = msgs.pop(0)
+            try:
+                image.optimize(screenshot_file, level=level)
+
+            except errors.ImageOptimizeError as e:
+                output_queue.put((daemon.MsgType.error, str(e)))
+
+            except errors.DependencyError as e:
+                if ignore_dependency_error:
+                    # Act like we optimized `screenshot_file`
+                    output_queue.put((daemon.MsgType.info, {
+                        'optimized_screenshot_path': screenshot_file,
+                    }))
+                else:
+                    raise e
+
+            else:
+                output_queue.put((daemon.MsgType.info, {
+                    'optimized_screenshot_path': screenshot_file,
+                }))
+
+
 def _get_video_files(output_queue, *, content_path, exclude_files):
     # Make list of appropriate video file(s) from `content_path`
     try:
@@ -422,3 +510,14 @@ def _maybe_terminate(*, input_queue):
     else:
         if typ == daemon.MsgType.terminate:
             raise SystemExit('Terminated')
+
+
+def _read_queue_until_empty(*, input_queue):
+    msgs = []
+    while True:
+        try:
+            typ, msg = input_queue.get(timeout=0.01)
+        except queue.Empty:
+            return msgs
+        else:
+            msgs.append((typ, msg))
