@@ -6,7 +6,6 @@ import abc
 import builtins
 import collections
 import functools
-import os
 import pathlib
 
 from ... import errors, jobs, utils
@@ -34,16 +33,17 @@ class TrackerJobsBase(abc.ABC):
     """
 
     def __init__(self, *, content_path, tracker,
-                 reuse_torrent_path=None, torrent_destination=None, check_after_add=False,
-                 exclude_files=(), options=None, image_host=None,
-                 bittorrent_client=None, common_job_args=None):
+                 reuse_torrent_path=None, exclude_files=(),
+                 btclient=None, torrent_destination=None,
+                 screenshots_optimization=None, image_host=None,
+                 options=None, common_job_args=None):
         self._content_path = content_path
         self._reuse_torrent_path = reuse_torrent_path
         self._tracker = tracker
+        self._screenshots_optimization = screenshots_optimization
         self._image_host = image_host
-        self._bittorrent_client = bittorrent_client
+        self._btclient = btclient
         self._torrent_destination = torrent_destination
-        self._check_after_add = check_after_add
         self._exclude_files = exclude_files
         self._common_job_args = common_job_args or {}
         self._options = options or {}
@@ -85,11 +85,6 @@ class TrackerJobsBase(abc.ABC):
         """
         return self._torrent_destination
 
-    @property
-    def check_after_add(self):
-        """Whether to hash existing files after adding the torrent to a client"""
-        return self._check_after_add
-
     @property
     def exclude_files(self):
         """
@@ -123,13 +118,13 @@ class TrackerJobsBase(abc.ABC):
         return self._image_host
 
     @property
-    def bittorrent_client(self):
+    def btclient(self):
         """
-        :class:`~.base.ClientApiBase` instance or `None`
+        :class:`~.btclient.BtClient` instance or `None`
 
         This is the same object that was passed as a initialization argument.
         """
-        return self._bittorrent_client
+        return self._btclient
 
     def common_job_args(self, **overload):
         """
@@ -318,11 +313,11 @@ class TrackerJobsBase(abc.ABC):
         that are only used for one tracker but might share the same name with
         other trackers.
         """
-        prefix = f'{self.tracker.name}-'
-        if name.startswith(prefix):
+        suffix = f'.{self.tracker.name}'
+        if name.endswith(suffix):
             return name
         else:
-            return f'{prefix}{name}'
+            return f'{name}{suffix}'
 
     @functools.cached_property
     def create_torrent_job(self):
@@ -336,28 +331,23 @@ class TrackerJobsBase(abc.ABC):
             **self.common_job_args(),
         )
 
-    torrent_piece_size_min = 2**20  # 1 MiB
-    """Minimum torrent piece size for this tracker"""
-
-    torrent_piece_size_max = 16 * 2**20  # 16 MiB
-    """Maximum torrent piece size for this tracker"""
-
     @functools.cached_property
     def add_torrent_job(self):
         """:class:`~.jobs.torrent.AddTorrentJob` instance"""
-        if self.bittorrent_client and self.create_torrent_job:
+        if self._btclient and self.create_torrent_job:
             add_torrent_job = jobs.torrent.AddTorrentJob(
                 autostart=False,
-                client_api=self.bittorrent_client,
-                download_path=utils.fs.dirname(os.path.abspath(self.content_path)),
-                check_after_add=self.check_after_add,
+                btclient=self._btclient,
                 precondition=self.make_precondition('add_torrent_job'),
                 **self.common_job_args(),
             )
+
             # Pass CreateTorrentJob output to AddTorrentJob input.
             self.create_torrent_job.signal.register('output', add_torrent_job.enqueue)
+
             # Tell AddTorrentJob to finish the current upload and then finish.
             self.create_torrent_job.signal.register('finished', self.finalize_add_torrent_job)
+
             return add_torrent_job
 
     def finalize_add_torrent_job(self, _):
@@ -432,6 +422,7 @@ class TrackerJobsBase(abc.ABC):
         await self.release_name_job.fetch_text(
             coro=self.release_name.fetch_info(webdb=webdb, webdb_id=webdb_id),
             nonfatal_exceptions=(errors.RequestError,),
+            default=str(self.release_name),
         )
         _log.debug('Updated release name: %s', self.release_name)
 
@@ -544,14 +535,15 @@ class TrackerJobsBase(abc.ABC):
         """
         :class:`~.jobs.screenshots.ScreenshotsJob` instance
 
-        The number of screenshots to make is taken from the ``screenshots``
-        value in :attr:`options`.
+        The number of screenshots to make is taken the :attr:`screenshots_count`
+        attribute.
         """
         return jobs.screenshots.ScreenshotsJob(
             content_path=self.content_path,
             exclude_files=self.exclude_files,
             count=self.screenshots_count,
             from_all_videos=self.screenshots_from_all_videos,
+            optimize=self._screenshots_optimization,
             precondition=self.make_precondition('screenshots_job'),
             **self.common_job_args(),
         )
@@ -562,7 +554,8 @@ class TrackerJobsBase(abc.ABC):
         How many screenshots to make
 
         The default implementation uses :attr:`options`\\ ``["screenshots"]``
-        with `None` as the default value.
+        with `None` as the default value, which creates a default number of
+        screenshots.
         """
         return self.options.get('screenshots')
 
@@ -802,17 +795,25 @@ class TrackerJobsBase(abc.ABC):
             **common_job_args,
         )
 
-    def make_precondition(self, job_attr):
+    def make_precondition(self, job_attr, precondition=None):
         """
         Return :attr:`~.base.JobBase.precondition` function for job
 
+        The returned function takes into account :attr:`jobs_before_upload`,
+        :attr:`jobs_after_upload` and :attr:`isolated_jobs`.
+
         :param str job_attr: Name of the job attribute this precondition is for
 
             By convention, this should be ``"<name>_job"``.
 
-        The returned function takes into account :attr:`jobs_before_upload`,
-        :attr:`jobs_after_upload` and :attr:`isolated_jobs`.
+        :param callable precondition: Custom :attr:`~.base.JobBase.precondition`
+
+            `precondition` must be either `None` or return anything truthy for
+            the job to get enabled.
         """
+        def custom_precondition(precondition=precondition):
+            return precondition is None or precondition()
+
         def precondition():
             job = getattr(self, job_attr)
             if not (
@@ -825,11 +826,11 @@ class TrackerJobsBase(abc.ABC):
             isolated_jobs = self.isolated_jobs
             if isolated_jobs and job in isolated_jobs:
                 # Jobs was isolated by user (i.e. other jobs are disabled)
-                return True
+                return custom_precondition()
 
             if not isolated_jobs:
                 # No isolated jobs means all jobs in jobs_before/after_upload are enabled
-                return True
+                return custom_precondition()
 
             return False
 
