@@ -157,6 +157,22 @@ class TrackerBase(abc.ABC):
     async def get_announce_url(self):
         """Get announce URL from tracker website"""
 
+    calculate_piece_size = None
+    """
+    :class:`staticmethod` that takes a torrent's content size and returns
+    the corresponding piece size
+
+    If this is `None`, the default implementation is used.
+    """
+
+    calculate_piece_size_min_max = None
+    """
+    :class:`staticmethod` that takes a torrent's content size and returns
+    the corresponding allowed minimum and maximum piece sizes
+
+    If this is `None`, the default implementation is used.
+    """
+
     @abc.abstractmethod
     async def upload(self, tracker_jobs):
         """
