@@ -15,8 +15,6 @@ _log = logging.getLogger(__name__)
 
 class MtvTrackerJobs(TrackerJobsBase):
 
-    torrent_piece_size_max = 8 * 2**20  # 8 MiB
-
     @functools.cached_property
     def jobs_before_upload(self):
         return (
@@ -77,8 +75,9 @@ class MtvTrackerJobs(TrackerJobsBase):
         """
         old_type = self.imdb_job.query.type
         new_type = self.chosen_release_type
-        _log.debug('Updating IMDb query from %s to %s', old_type, new_type)
-        self.imdb_job.query.type = new_type
+        if new_type is not None:
+            _log.debug('Updating IMDb query from %s to %s', old_type, new_type)
+            self.imdb_job.query.type = new_type
 
     _categories = (
         {'label': 'HD Season', 'value': '5', 'type': ReleaseType.season},
@@ -148,13 +147,13 @@ class MtvTrackerJobs(TrackerJobsBase):
         return jobs.dialog.TextFieldJob(
             name=self.get_job_name('title'),
             label='Title',
+            precondition=self.make_precondition('title_job'),
             prejobs=(
                 self.category_job,
                 self.scene_check_job,
                 self.imdb_job,
             ),
             text=self.generate_title,
-            precondition=self.make_precondition('title_job'),
             **self.common_job_args(),
         )
 
@@ -183,13 +182,13 @@ class MtvTrackerJobs(TrackerJobsBase):
         return jobs.dialog.TextFieldJob(
             name=self.get_job_name('description'),
             label='Description',
+            precondition=self.make_precondition('description_job'),
             prejobs=(
                 self.mediainfo_job,
                 self.upload_screenshots_job,
             ),
             text=self.generate_description,
-            precondition=self.make_precondition('description_job'),
-            autofinish=True,
+            finish_on_success=True,
             read_only=True,
             hidden=True,
             # Don't cache job output because the number of screenshots can be
