@@ -115,6 +115,14 @@ class MtvTracker(TrackerBase):
                 # self.logout()
                 pass
 
+    @staticmethod
+    def calculate_piece_size_min_max(bytes):
+        """Anything from 32 KiB to 8 MiB is fine, regardless of content size"""
+        return (
+            32 * 1024,        # 32 KiB
+            8 * (1024 ** 2),  # 8 MiB
+        )
+
     async def upload(self, tracker_jobs):
         autofill_post_data = await self._make_autofill_request(tracker_jobs)
         _log.debug('Autofill data: %r', autofill_post_data)
