@@ -2,8 +2,9 @@
 Concrete :class:`~.base.TrackerJobsBase` subclass for NBL
 """
 
+import functools
+
 from ... import jobs, utils
-from ...utils import cached_property
 from .. import base
 
 import logging  # isort:skip
@@ -11,7 +12,7 @@ _log = logging.getLogger(__name__)
 
 
 class NblTrackerJobs(base.TrackerJobsBase):
-    @cached_property
+    @functools.cached_property
     def jobs_before_upload(self):
         return (
             self.create_torrent_job,
@@ -20,7 +21,7 @@ class NblTrackerJobs(base.TrackerJobsBase):
             self.category_job,
         )
 
-    @cached_property
+    @functools.cached_property
     def category_job(self):
         return jobs.dialog.ChoiceJob(
             name=self.get_job_name('category'),
@@ -34,7 +35,7 @@ class NblTrackerJobs(base.TrackerJobsBase):
             **self.common_job_args(),
         )
 
-    @cached_property
+    @functools.cached_property
     def autodetected_category(self):
         if self.release_name.type is utils.release.ReleaseType.season:
             return 'Season'
