@@ -2,6 +2,7 @@
 Concrete :class:`~.base.TrackerBase` subclass for PTP
 """
 
+import math
 import re
 import urllib
 
@@ -19,7 +20,34 @@ class PtpTracker(TrackerBase):
     label = 'PTP'
 
     setup_howto_template = (
-        'TODO'
+        '{howto.introduction}\n'
+        '\n'
+        '{howto.current_section}. Login Credentials\n'
+        '\n'
+        '   {howto.current_section}.1 $ upsies set trackers.ptp.username USERNAME\n'
+        '   {howto.current_section}.2 $ upsies set trackers.ptp.password PASSWORD\n'
+        '{howto.bump_section}'
+        '\n'
+        '{howto.current_section}. Announce URL\n'
+        '\n'
+        '   The announce URL is required because the passkey is used for 2FA.\n'
+        '\n'
+        '   {howto.current_section}.1 $ upsies set trackers.ptp.announce_url ANNOUNCE_URL\n'
+        '{howto.bump_section}'
+        '\n'
+        '{howto.current_section}. Screenshots\n'
+        '\n'
+        '   {howto.current_section}.1 Configure ptpimg.me API\n'
+        '       $ upsies upload-images ptpimg --help\n'
+        '\n'
+        '   {howto.current_section}.2 Specify how many screenshots to make. (optional)\n'
+        '       $ upsies set trackers.ptp.screenshots_from_movie NUMBER_OF_MOVIE_SCREENSHOTS\n'
+        '       $ upsies set trackers.ptp.screenshots_from_episode NUMBER_OF_EPISODE_SCREENSHOTS\n'
+        '{howto.bump_section}'
+        '\n'
+        '{howto.autoseed}\n'
+        '\n'
+        '{howto.upload}\n'
     )
 
     TrackerConfig = PtpTrackerConfig
@@ -116,11 +144,11 @@ class PtpTracker(TrackerBase):
                 and json.get('Result') == 'Error'
                 and json.get('Message')
             ):
-                raise errors.RequestError(json['Message'])
+                raise errors.RequestError(utils.html.as_text(json['Message']))
 
     def _maybe_raise_error_from_html(self, response_or_request_error):
         # Only attempt to find an error message if this looks like HTML. This
-        # prevents a warning from bs4 that tries to be helpful.
+        # prevents a warning from bs4 about parsing non-HTML.
         text = str(response_or_request_error)
         if all(c in text for c in '<>\n'):
             doc = utils.html.parse(text)
@@ -137,22 +165,22 @@ class PtpTracker(TrackerBase):
 
     def _get_anti_csrf_token(self, response):
         json = response.json()
-        return json['AntiCsrfToken']
-
-    _auth_regex = re.compile(r'logout\.php\?.*\bauth=([0-9a-fA-F]+)')
+        try:
+            return json['AntiCsrfToken']
+        except KeyError:
+            _log.debug('Failed to find "AntiCsrfToken": %r', response)
+            raise
 
     async def _get_auth(self):
         assert self.is_logged_in
         response = await self._request('GET', self._base_url)
         doc = utils.html.parse(response)
-
-        try:
-            logout_link_tag = doc.find('a', href=self._auth_regex)
+        auth_regex = re.compile(r'logout\.php\?.*\bauth=([0-9a-fA-F]+)')
+        logout_link_tag = doc.find('a', href=auth_regex)
+        if logout_link_tag:
             logout_link_href = logout_link_tag['href']
-            match = self._auth_regex.search(logout_link_href)
+            match = auth_regex.search(logout_link_href)
             return match.group(1)
-        except (AttributeError, KeyError, TypeError):
-            pass
 
         raise RuntimeError('Could not find auth')
 
@@ -174,6 +202,9 @@ class PtpTracker(TrackerBase):
             url=f'{self._ajax_url}?action=login',
             data=post_data,
             error_prefix='Login failed',
+
+            # TODO: Remove this before release
+            debug_file='http_dumps.ptp/ptp_login',
         )
         self._anti_csrf_token = self._get_anti_csrf_token(response)
 
@@ -185,6 +216,9 @@ class PtpTracker(TrackerBase):
                 url=self._logout_url,
                 params={'auth': await self._get_auth()},
                 error_prefix='Logout failed',
+
+                # TODO: Remove this before release
+                debug_file='http_dumps.ptp/ptp_logout',
             )
 
         finally:
@@ -195,11 +229,12 @@ class PtpTracker(TrackerBase):
         return self._announce_url
 
     async def upload(self, tracker_jobs):
-        post_data = tracker_jobs.post_data
+        post_data = tracker_jobs.post_data.copy()
         post_data['AntiCsrfToken'] = self._anti_csrf_token
+
         _log.debug('POSTing data:')
         for k, v in post_data.items():
-            _log.debug(' * %s = %r', k, v)
+            _log.debug(' * %s = %s', k, v)
 
         post_files = {
             'file_input': {
@@ -209,17 +244,53 @@ class PtpTracker(TrackerBase):
         }
         _log.debug('POSTing files: %r', post_files)
 
-        # response = await utils.http.post(
-        #     url=self._upload_url,
-        #     cache=False,
-        #     user_agent=True,
-        #     # Can we use this to get the page of the uploaded torrent?
-        #     # follow_redirects=False,
-        #     data=post_data,
-        #     files=post_files,
+        response = await utils.http.post(
+            url=self._upload_url,
+            cache=False,
+            user_agent=True,
+            data=post_data,
+            files=post_files,
+            # Ignore the HTTP redirect (should be 302 Found) so we can get the
+            # torrent URL from the "Location" response header
+            follow_redirects=False,
+
+            # TODO: Remove this before release
+            debug_file='http_dumps.ptp/ptp_upload',
+        )
+
+        # # Read previously received response for debugging
+        # response_filepath = 'ptp_upload.response.content'
+        # response = utils.http.Response(
+        #     text=open(response_filepath).read(),
+        #     bytes=open(response_filepath).read().encode('utf8'),
         # )
 
-        self.error('PTP support is not done yet.')
+        return self._handle_upload_response(response)
+
+    def _handle_upload_response(self, response):
+        # "Location" header should contain the uploaded torrent's URL
+        _log.debug('Upload response headers: %r', response.headers)
+        location = response.headers.get('Location')
+        _log.debug('Upload response location: %r', location)
+        if location:
+            torrent_page_url = urllib.parse.urljoin(self.options['base_url'], location)
+            # Redirect URL should start with "https://.../torrents.php"
+            if torrent_page_url.startswith(self._torrents_url):
+                return torrent_page_url
+
+        # Find error message in HTML
+        doc = utils.html.parse(response)
+
+        # Find and raise error message
+        alert_tag = doc.find(class_='alert')
+        if alert_tag:
+            msg = utils.html.as_text(alert_tag)
+            raise errors.RequestError(f'Upload failed: {msg}')
+
+        # Failed to find error message
+        dump_filepath = 'ptp_upload_failed.html'
+        utils.html.dump(response, dump_filepath)
+        raise errors.RequestError(f'Failed to interpret response (see {dump_filepath})')
 
     def normalize_imdb_id(self, imdb_id):
         """
@@ -228,12 +299,16 @@ class PtpTracker(TrackerBase):
         PTP expects 7-characters, right-padded with "0" and without the leading
         "tt".
 
-        If `imdb_id` is `None`, return "0".
+        If `imdb_id` is falsy (e.g. `None`, empty string, etc), or if it isn't
+        an IMDb ID, return "0".
         """
-        if imdb_id is None:
-            return '0'
-        else:
-            return str(imdb_id).lstrip('t').rjust(7, '0')
+        imdb_id = str(imdb_id)
+        match = re.search(r'^(?:tt|)(\d+)$', imdb_id)
+        if match:
+            imdb_id_digits = match.group(1)
+            if set(imdb_id_digits) != {'0'}:
+                return match.group(1).rjust(7, '0')
+        return '0'
 
     async def get_ptp_group_id_by_imdb_id(self, imdb_id):
         """
@@ -281,7 +356,7 @@ class PtpTracker(TrackerBase):
         if key:
             _log.debug('%s: Fetching %s from PTP', imdb_id, key)
         else:
-            _log.debug('%s: Fetching metadata from PTP', imdb_id, key)
+            _log.debug('%s: Fetching metadata from PTP', imdb_id)
 
         assert imdb_id, imdb_id
 
@@ -310,3 +385,52 @@ class PtpTracker(TrackerBase):
             else:
                 _log.debug('%s: PTP %s: %s', imdb_id, key, results[0][key])
                 return results[0][key]
+
+    @staticmethod
+    def calculate_piece_size(bytes):
+        """
+        Return the recommended piece size for a given content size
+
+        :param bytes: Torrent's content size
+
+            .. note:: Remember to exclude files that exist but won't be in the
+                torrent (e.g. extras or ``*.nfo``).
+        """
+        exponent = math.ceil(math.log2(bytes / 1050))
+        # Allowed piece size range: 32 KiB ... 16 MiB
+        exponent = min(24, max(15, exponent))
+        return int(math.pow(2, exponent))
+
+    @staticmethod
+    def calculate_piece_size_min_max(bytes):
+        """
+        Return the allowed minimum and maximum piece size for a given
+        content size
+
+        :param bytes: Torrent's content size
+
+            .. note:: Remember to exclude files that exist but won't be in the
+                torrent (e.g. extras or ``*.nfo``).
+
+        :raise ValueError: if `bytes` is negative or otherwise unexpected
+        """
+        # All numbers are from PTP's piece size chart.
+        # (MIN_SIZE, MAX_SIZE): (PIECE_SIZE_MIN, PIECE_SIZE_MAX)
+        allowed_piece_sizes = {
+            (0, 147 * 1024 * 1024 - 1): (2**15, 2**16),
+            (147 * 1024 * 1024, 256 * 1024 * 1024 - 1): (2**16, 2**19),
+            (256 * 1024 * 1024, 533 * 1024 * 1024 - 1): (2**17, 2**20),
+            (533 * 1024 * 1024, 1.08 * 1024 * 1024 * 1024 - 1): (2**18, 2**21),
+            (1.08 * 1024 * 1024 * 1024, 2.24 * 1024 * 1024 * 1024 - 1): (2**19, 2**22),
+            (2.24 * 1024 * 1024 * 1024, 4.65 * 1024 * 1024 * 1024 - 1): (2**20, 2**23),
+            (4.65 * 1024 * 1024 * 1024, 8.04 * 1024 * 1024 * 1024 - 1): (2**21, 2**24),
+            (8.04 * 1024 * 1024 * 1024, 148.75 * 1024 * 1024 * 1024 - 1): (2**22, 2**24),
+            (148.75 * 1024 * 1024 * 1024, 257.04 * 1024 * 1024 * 1024 - 1): (2**23, 2**24),
+            (257.04 * 1024 * 1024 * 1024, float('inf')): (2**24, 2**24),
+        }
+
+        for (min_size, max_size), (piece_size_min, piece_size_max) in allowed_piece_sizes.items():
+            if min_size <= bytes <= max_size:
+                return piece_size_min, piece_size_max
+
+        raise ValueError(f'Unexpected size: {bytes!r}')
