@@ -2,6 +2,7 @@
 Change or show configuration file options
 """
 
+import functools
 import textwrap
 
 from .... import constants, defaults, errors, jobs, utils
@@ -98,7 +99,7 @@ class set(CommandBase):
         },
     }
 
-    @utils.cached_property
+    @functools.cached_property
     def jobs(self):
         if self.args.fetch_ptpimg_apikey is not None:
             return (self.fetch_ptpimg_apikey_job,)
@@ -114,7 +115,7 @@ class set(CommandBase):
                 ),
             )
 
-    @utils.cached_property
+    @functools.cached_property
     def fetch_ptpimg_apikey_job(self):
         return jobs.custom.CustomJob(
             name='fetch-ptpimg-apikey',
