@@ -3,8 +3,7 @@ Generate all required metadata and upload to tracker
 """
 
 import functools
-
-import aiobtclientapi
+import os
 
 from .... import __project_name__, constants, jobs, trackers, utils
 from . import base
@@ -80,7 +79,7 @@ class submit(base.CommandBase):
                         'type': utils.argtypes.client,
                         'metavar': 'CLIENT',
                         'help': ('Case-insensitive BitTorrent client name\n'
-                                 'Supported clients: ' + ', '.join(aiobtclientapi.client_names())),
+                                 'Supported clients: ' + ', '.join(utils.btclient.client_names())),
                     },
                     ('--copy-to', '-c'): {
                         'metavar': 'PATH',
@@ -148,10 +147,10 @@ class submit(base.CommandBase):
                 + tuple(self.config['config']['torrent-create']['reuse_torrent_paths'])
             ),
             tracker=self.tracker,
+            screenshots_optimization=self.config['config']['screenshots']['optimize'],
             image_host=self._get_imghost(),
-            bittorrent_client=self._get_btclient(),
+            btclient=self._get_btclient(),
             torrent_destination=self._get_torrent_destination(),
-            check_after_add=self._get_check_after_add(),
             exclude_files=(
                 tuple(self.config['trackers'][self.tracker.name]['exclude'])
                 + tuple(self.args.exclude_files)
@@ -187,22 +186,19 @@ class submit(base.CommandBase):
                 or None)
 
     def _get_btclient(self):
-        btclient_name = self._get_btclient_name()
-        if btclient_name:
-            options = self.get_options('clients', btclient_name)
-            return aiobtclientapi.api(
-                name=btclient_name,
+        client_name = self._get_btclient_name()
+        if client_name:
+            options = self.get_options('clients', client_name)
+            return utils.btclient.BtClient(
+                name=client_name,
                 url=options['url'],
                 username=options['username'],
                 password=options['password'],
+                download_path=utils.fs.dirname(os.path.abspath(self.args.CONTENT)),
+                check_after_add=options['check_after_add'],
             )
 
     def _get_torrent_destination(self):
         return (getattr(self.args, 'copy_to', None)
                 or self.tracker_options.get('copy_to', None)
                 or None)
-
-    def _get_check_after_add(self):
-        btclient_config = self.config['clients'].get(self._get_btclient_name())
-        if btclient_config:
-            return btclient_config['check_after_add']
