@@ -5,8 +5,6 @@ Commands related to torrent files
 import functools
 import os
 
-import aiobtclientapi
-
 from .... import constants, jobs, trackers, utils
 from .base import CommandBase
 
@@ -20,7 +18,7 @@ class torrent_add(CommandBase):
         'CLIENT': {
             'type': utils.argtypes.client,
             'help': ('Case-insensitive BitTorrent client name\n'
-                     'Supported clients: ' + ', '.join(aiobtclientapi.client_names())),
+                     'Supported clients: ' + ', '.join(utils.btclient.client_names())),
         },
         'TORRENT': {
             'nargs': '+',
@@ -41,14 +39,14 @@ class torrent_add(CommandBase):
                 home_directory=self.home_directory,
                 cache_directory=self.cache_directory,
                 ignore_cache=self.args.ignore_cache,
-                client_api=aiobtclientapi.api(
+                btclient=utils.btclient.BtClient(
                     name=client_name,
                     url=options['url'],
                     username=options['username'],
                     password=options['password'],
+                    download_path=self.args.download_path,
+                    check_after_add=options['check_after_add'],
                 ),
-                download_path=self.args.download_path,
-                check_after_add=options['check_after_add'],
                 enqueue=self.args.TORRENT,
             ),
         )
@@ -105,7 +103,7 @@ class torrent_create(CommandBase):
                                  f'{utils.fs.tildify_path(constants.GENERIC_TORRENTS_DIRPATH)}\n'
                                  'TORRENT may also be a directory, which is searched recursively '
                                  'for a matching *.torrent file.\n'
-                                 "NOTE: This option is ignored if TORRENT doesn't match properly."),
+                                 "NOTE: This option is ignored if TORRENT doesn't match CONTENT properly."),
                         'type': utils.argtypes.existing_path,
                         'default': (),
                     },
@@ -113,7 +111,7 @@ class torrent_create(CommandBase):
                         'type': utils.argtypes.client,
                         'metavar': 'CLIENT',
                         'help': ('Case-insensitive BitTorrent client name\n'
-                                 'Supported clients: ' + ', '.join(aiobtclientapi.client_names())),
+                                 'Supported clients: ' + ', '.join(utils.btclient.client_names())),
                     },
                     ('--copy-to', '-c'): {
                         'metavar': 'PATH',
@@ -163,26 +161,29 @@ class torrent_create(CommandBase):
     def add_torrent_job(self):
         if self.args.add_to:
             client_name = self.args.add_to
-            config = self.config['clients'][client_name]
+            options = self.get_options('clients', client_name)
             add_torrent_job = jobs.torrent.AddTorrentJob(
                 home_directory=self.home_directory,
                 cache_directory=self.cache_directory,
                 ignore_cache=self.args.ignore_cache,
-                client_api=aiobtclientapi.api(
+                btclient=utils.btclient.BtClient(
                     name=client_name,
-                    url=config['url'],
-                    username=config['username'],
-                    password=config['password'],
+                    url=options['url'],
+                    username=options['username'],
+                    password=options['password'],
+                    download_path=utils.fs.dirname(os.path.abspath(self.args.CONTENT)),
+                    check_after_add=options['check_after_add'],
                 ),
-                download_path=utils.fs.dirname(os.path.abspath(self.args.CONTENT)),
-                check_after_add=config['check_after_add'],
             )
+
             # Pass CreateTorrentJob output to AddTorrentJob input.
             self.create_torrent_job.signal.register('output', add_torrent_job.enqueue)
+
             # Finish AddTorrentJob when CreateTorrentJob is finished. The
             # torrent will be enqueued and AddTorrentJob will finish after
             # adding the enqueued torrent.
             self.create_torrent_job.signal.register('finished', lambda _: add_torrent_job.finalize())
+
             return add_torrent_job
 
     @functools.cached_property
