@@ -1,10 +1,9 @@
 import abc
-from functools import cached_property
+import functools
 
 from prompt_toolkit.filters import Condition
 from prompt_toolkit.key_binding import KeyBindings
-from prompt_toolkit.layout.containers import (ConditionalContainer, HSplit,
-                                              Window, to_container)
+from prompt_toolkit.layout.containers import ConditionalContainer, HSplit, Window, to_container
 from prompt_toolkit.layout.controls import FormattedTextControl
 from prompt_toolkit.layout.layout import walk
 
@@ -93,7 +92,7 @@ class JobWidgetBase(abc.ABC):
             `None`
         """
 
-    @cached_property
+    @functools.cached_property
     def _runtime_widget(self):
         runtime_widget = self.runtime_widget
         if runtime_widget:
@@ -169,7 +168,7 @@ class JobWidgetBase(abc.ABC):
                     return True
         return False
 
-    @cached_property
+    @functools.cached_property
     def keybindings_global(self):
         """
         Application-wide :class:`prompt_toolkit.key_binding.KeyBindings` instance
@@ -188,7 +187,7 @@ class JobWidgetBase(abc.ABC):
         """
         return self._app.key_bindings
 
-    @cached_property
+    @functools.cached_property
     def keybindings_local(self):
         """
         Widget-wide :class:`prompt_toolkit.key_binding.KeyBindings` instance
