@@ -1,4 +1,5 @@
-from ....utils import cached_property
+import functools
+
 from . import JobWidgetBase
 
 
@@ -6,6 +7,6 @@ class CustomJobWidget(JobWidgetBase):
     def setup(self):
         pass
 
-    @cached_property
+    @functools.cached_property
     def runtime_widget(self):
         return None
