@@ -1,4 +1,5 @@
-from ....utils import cached_property
+import functools
+
 from . import JobWidgetBase
 
 import logging  # isort:skip
@@ -28,6 +29,6 @@ class PosterJobWidget(JobWidgetBase):
     def handle_uploaded_poster(self, url):
         self.invalidate()
 
-    @cached_property
+    @functools.cached_property
     def runtime_widget(self):
         return None
