@@ -1,9 +1,9 @@
+import functools
+
 from prompt_toolkit.filters import Condition
-from prompt_toolkit.layout.containers import (ConditionalContainer, HSplit,
-                                              Window)
+from prompt_toolkit.layout.containers import ConditionalContainer, HSplit, Window
 from prompt_toolkit.layout.controls import FormattedTextControl
 
-from ....utils import cached_property
 from ....utils.types import SceneCheckResult
 from .. import widgets
 from . import JobWidgetBase
@@ -16,7 +16,7 @@ class SceneSearchJobWidget(JobWidgetBase):
     def setup(self):
         pass
 
-    @cached_property
+    @functools.cached_property
     def runtime_widget(self):
         return None
 
@@ -98,7 +98,7 @@ class SceneCheckJobWidget(JobWidgetBase):
         self._question.text = 'Is this a scene release?'
         self.invalidate()
 
-    @cached_property
+    @functools.cached_property
     def runtime_widget(self):
         return HSplit(
             children=[
