@@ -1,7 +1,9 @@
+import functools
+
 from prompt_toolkit.filters import Condition
 from prompt_toolkit.layout.containers import ConditionalContainer, HSplit
 
-from ....utils import cached_property, fs
+from ....utils import fs
 from .. import widgets
 from . import JobWidgetBase
 
@@ -29,7 +31,7 @@ class ScreenshotsJobWidget(JobWidgetBase):
         if self.job.screenshots_total > 0:
             self._screenshot_progress.percent = self.job.screenshots_created / self.job.screenshots_total * 100
 
-    @cached_property
+    @functools.cached_property
     def runtime_widget(self):
         return HSplit(
             children=[
