@@ -1,5 +1,6 @@
+import functools
+
 from .... import __project_name__, errors
-from ....utils import cached_property
 from . import JobWidgetBase
 
 
@@ -15,6 +16,6 @@ class SubmitJobWidget(JobWidgetBase):
         elif isinstance(error, errors.FoundDupeError):
             self.job.error('You can override the dupe check with --ignore-dupes.')
 
-    @cached_property
+    @functools.cached_property
     def runtime_widget(self):
         return None
