@@ -1,11 +1,11 @@
+import functools
+
 from prompt_toolkit.filters import Condition
-from prompt_toolkit.layout.containers import (ConditionalContainer,
-                                              HorizontalAlign, HSplit, VSplit,
-                                              Window, WindowAlign)
+from prompt_toolkit.layout.containers import ConditionalContainer, HorizontalAlign, HSplit, VSplit, Window, WindowAlign
 from prompt_toolkit.layout.controls import FormattedTextControl
 from prompt_toolkit.layout.dimension import Dimension
 
-from ....utils import cached_property, fs, torrent
+from ....utils import fs, torrent
 from .. import widgets
 from . import JobWidgetBase
 
@@ -205,7 +205,7 @@ class CreateTorrentJobWidget(JobWidgetBase):
 
         return activity
 
-    @cached_property
+    @functools.cached_property
     def runtime_widget(self):
         return self._runtime_widget
 
@@ -214,7 +214,7 @@ class AddTorrentJobWidget(JobWidgetBase):
     def setup(self):
         pass
 
-    @cached_property
+    @functools.cached_property
     def runtime_widget(self):
         return None
 
@@ -223,6 +223,6 @@ class CopyTorrentJobWidget(JobWidgetBase):
     def setup(self):
         pass
 
-    @cached_property
+    @functools.cached_property
     def runtime_widget(self):
         return None
