@@ -1,9 +1,10 @@
-from prompt_toolkit.layout.containers import (DynamicContainer, HSplit, VSplit,
-                                              Window)
+import functools
+
+from prompt_toolkit.layout.containers import DynamicContainer, HSplit, VSplit, Window
 from prompt_toolkit.layout.controls import FormattedTextControl
 from prompt_toolkit.utils import get_cwidth
 
-from ....utils import browser, cached_property, webdbs
+from ....utils import browser, webdbs
 from .. import widgets
 from . import JobWidgetBase
 
@@ -112,7 +113,7 @@ class WebDbSearchJobWidget(JobWidgetBase):
         self._widgets['query'].set_text(str(text))
         self._old_query_text = self._widgets['query'].text
 
-    @cached_property
+    @functools.cached_property
     def runtime_widget(self):
         w = self._widgets
         layout = [
