@@ -5,8 +5,7 @@ Entry point
 import asyncio
 import sys
 
-from ... import (__homepage__, __project_name__, application_setup,
-                 application_shutdown, errors)
+from ... import __homepage__, __project_name__, application_setup, application_shutdown, errors
 from ...utils import get_aioloop, update
 from . import commands, utils
 
