@@ -200,51 +200,54 @@ class MonitoredList(collections.abc.MutableSequence):
         return f'{type(self).__name__}({repr(self._list)}, callback={self._callback!r})'
 
 
-class RestrictedMapping(collections.abc.MutableMapping):
+class ImmutableMapping(collections.abc.Mapping):
     """
-    :class:`dict` that only accepts the keys provided when it was instantiated
+    :class:`dict`-like that can't be changed after initialization
 
-    >>> d = RestrictedMapping({'foo': 'bar'})
-    >>> d['foo']
-    >>> 'bar'
-    >>> d['baz']
-    >>> KeyError: 'baz'
-
-    >>> d = RestrictedMapping(allowed_keys=('foo', 'bar'), foo=1, bar=2)
-    >>> d['foo']
-    >>> 1
-    >>> d['baz']
-    >>> KeyError: 'baz'
+    All values are also made immutable recursively. Keys should already be
+    immutable because the must be hashable.
     """
 
-    def __init__(self, *args, allowed_keys=(), **kwargs):
-        self._allowed_keys = set(allowed_keys)
-        if len(args) == 1 and isinstance(args[0], collections.abc.Mapping):
-            self._allowed_keys.update(args[0])
-            self._dict = dict(args[0])
+    def __init__(self, *args, **kwargs):
+        self._dct = {
+            k: self._make_immutable(v)
+            for k, v in dict(*args, **kwargs).items()
+        }
+
+    def _make_immutable(self, obj):
+        if isinstance(obj, str):
+            # Catch strings early because they are also sequences
+            return obj
+
+        elif isinstance(obj, collections.abc.Sequence):
+            return tuple(self._make_immutable(item) for item in obj)
+
+        elif isinstance(obj, collections.abc.Mapping):
+            return ImmutableMapping(obj)
+
         else:
-            self._dict = dict(*args, **kwargs)
+            return obj
 
     def __getitem__(self, key):
-        return self._dict[key]
-
-    def __setitem__(self, key, value):
-        if key in self._allowed_keys:
-            self._dict[key] = value
-        else:
-           raise KeyError(key)
-
-    def __delitem__(self, key):
-        del self._dict[key]
+        return self._dct[key]
 
     def __iter__(self):
-        return iter(self._dict)
+        return iter(self._dct)
 
     def __len__(self):
-        return len(self._dict)
+        return len(self._dct)
+
+    def __hash__(self):
+        return hash(tuple(frozenset(self._dct.items())))
+
+    def __eq__(self, other):
+        if isinstance(other, collections.abc.Mapping):
+            return hash(self) == hash(tuple(frozenset(self._dct.items())))
+        else:
+            return NotImplemented
 
     def __repr__(self):
-        return repr(self._dict)
+        return f'{type(self).__name__}({repr(self._dct)})'
 
 
 def is_sequence(obj):
@@ -446,6 +449,7 @@ async def run_async(function, *args, **kwargs):
 from . import (  # noqa: E402 isort:skip
     argtypes,
     browser,
+    btclient,
     configfiles,
     country,
     daemon,
@@ -459,6 +463,7 @@ from . import (  # noqa: E402 isort:skip
     signal,
     string,
     subproc,
+    subtitle,
     timestamp,
     torrent,
     types,
