@@ -40,10 +40,10 @@ def comma_separated(argtype):
 
 
 def client(value):
-    """Name of a BitTorrent client supported by :mod:`aiobtclientapi`"""
-    import aiobtclientapi
+    """Name of a supported BitTorrent client"""
+    from . import btclient
     name = value.lower()
-    if name in aiobtclientapi.client_names():
+    if name in btclient.client_names():
         return name
     else:
         raise argparse.ArgumentTypeError(f'Unsupported client: {value}')
@@ -110,6 +110,25 @@ def option(value):
         raise argparse.ArgumentTypeError(f'Unknown option: {value}')
 
 
+@functools.lru_cache(maxsize=None)
+def one_of(values):
+    """
+    Return function that returns an item of `values` or raises
+    :class:`argparse.ArgumentTypeError`
+
+    :param values: Allowed values
+    """
+    values = tuple(values)
+
+    def one_of_values(value):
+        if value in values:
+            return value
+        else:
+            raise argparse.ArgumentTypeError(f'Invalid value: {value}')
+
+    return one_of_values
+
+
 def regex(value):
     """:class:`re.Pattern` object"""
     import re
