@@ -1,5 +1,5 @@
 """
-Lookup country information
+Look up country information
 """
 
 import functools
@@ -62,7 +62,4 @@ def tld(country):
 
     :return: Country TLD or `country` if it can't be associated with any country
     """
-    def as_tld(tld):
-        return ('uk' if tld == 'GB' else tld).lower()
-
-    return as_tld(iso2(country))
+    return _guess_country(country, attribute='cctld', default=country)
