@@ -17,6 +17,15 @@ _log = logging.getLogger(__name__)
 natsort = LazyModule(module='natsort', namespace=globals())
 
 
+OS_SEP_REGEX = re.escape(os.sep)
+r"""
+:attr:`os.sep` escaped with :func:`re.escape`
+
+On Windows, this should be ``"\\"`` while it should be identical to
+:attr:`os.sep` on Unix-likes.
+"""
+
+
 def assert_file_readable(filepath):
     """Raise :exc:`~.ContentError` if `open(filepath)` fails"""
     try:
@@ -172,14 +181,17 @@ def mkdir(path):
 
     Existing directories are ignored.
 
+    If `path` is empty, no directory is created.
+
     :raise ContentError: if directory creation fails
     """
-    try:
-        os.makedirs(path, exist_ok=True)
-    except OSError as e:
-        raise errors.ContentError(f'{path}: {e.strerror or e}')
-    else:
-        assert_dir_usable(path)
+    if path:
+        try:
+            os.makedirs(path, exist_ok=True)
+        except OSError as e:
+            raise errors.ContentError(f'{path}: {e.strerror or e}')
+        else:
+            assert_dir_usable(path)
 
 
 def basename(path, parents=0):
@@ -345,6 +357,22 @@ def file_size(path):
     return None
 
 
+def path_size(path):
+    """
+    Combined size of all files beneath `path`
+
+    Returns the same value as :func:`file_size` if `path` is not a directory.
+
+    Symbolic links are ignored.
+    """
+    filepaths = file_list(path, follow_dirlinks=False)
+    return sum(
+        file_size(f) or 0
+        for f in filepaths
+        if not os.path.islink(f)
+    )
+
+
 def file_list(path, extensions=(), min_age=None, max_age=None, follow_dirlinks=False):
     """
     List naturally sorted files in `path` and any subdirectories
@@ -359,6 +387,7 @@ def file_list(path, extensions=(), min_age=None, max_age=None, follow_dirlinks=F
 
     :param str path: Path to a directory
     :param str extensions: Only include files with one of these extensions
+        (matched case-insensitively)
     :param min_age: Exclude files that are younger than this
     :type min_age: int or float
     :param max_age: Exclude files that are older than this
@@ -417,6 +446,32 @@ def file_list(path, extensions=(), min_age=None, max_age=None, follow_dirlinks=F
     return tuple(natsort.natsorted(files, key=str.casefold))
 
 
+def find_name(name, path, validator=None):
+    """
+    Return first path (in human sort order) to `name` anywhere beneath
+    `path` or `None`
+
+    :param str name: Exact name of the file or directory
+    :param str path: Base path to search for `name`
+
+    :param validator: Callable that gets a path that ends with `name` and
+        returns whether it is a match or not
+
+        For example, you can use :func:`os.path.isfile` or :func:`os.path.isdir`
+        to only find files or directories.
+    """
+    for root_, dirnames_, filenames_ in natsort.natsorted(
+            os.walk(path, topdown=True, followlinks=False),
+    ):
+        names_ = natsort.natsorted(filenames_ + dirnames_)
+        for name_ in names_:
+            path_ = os.path.join(root_, name_)
+            if name_ == name and (
+                    not validator or validator(path_)
+            ):
+                return path_
+
+
 # Stolen from torf-cli
 # https://github.com/rndusr/torf-cli/blob/master/torfcli/_utils.py
 
