@@ -307,7 +307,12 @@ async def _request(
         if isinstance(data, (bytes, str)):
             build_request_args = {'content': data}
         else:
-            build_request_args = {'data': data}
+            # Remove fields with a value of `None`
+            build_request_args = {'data': {
+                k: v
+                for k, v in data.items()
+                if v is not None
+            }}
         request = client.build_request(
             method=str(method),
             url=str(url),
@@ -411,6 +416,7 @@ async def _dump_req_res(r, filepath):
         _log.debug('Response headers: %r', r.headers)
         _log.debug('Response data: %r', content)
 
+    utils.fs.mkdir(os.path.dirname(filepath))
     if isinstance(content, str):
         utils.html.dump(content, f'{filepath}.html')
     elif isinstance(content, bytes):
