@@ -21,8 +21,54 @@ def _ffmpeg_executable():
 
 
 def _make_screenshot_cmd(video_file, timestamp, screenshot_file):
-    # ffmpeg's "image2" image file muxer uses "%" for string formatting
+    # ffmpeg's "image2" image file muxer uses "%" for string formatting, so we
+    # must escape "%" in `video_file`
     screenshot_file = screenshot_file.replace('%', '%%')
+
+    # -vf argument from:
+    # https://rendezvois.github.io/video/screenshots/programs-choices/#ffmpeg
+
+    vf_flags = (
+        'full_chroma_int',
+        'full_chroma_inp',
+        'accurate_rnd',
+        'spline',
+    )
+
+    if utils.video.is_bt2020(video_file):
+        vf = ':'.join((
+            'scale=in_h_chr_pos=0',
+            'in_v_chr_pos=0',
+            'in_color_matrix=bt2020',
+            'flags=' + '+'.join(vf_flags),
+        ))
+
+    elif utils.video.is_bt709(video_file):
+        vf = ':'.join((
+            "scale='max(sar,1)*iw':'max(1/sar,1)*ih'",
+            'in_h_chr_pos=0',
+            'in_v_chr_pos=128',
+            'in_color_matrix=bt709',
+            'flags=' + '+'.join(vf_flags),
+        ))
+
+    elif utils.video.is_bt601(video_file):
+        vf = ':'.join((
+            "scale='max(sar,1)*iw':'max(1/sar,1)*ih'",
+            'in_h_chr_pos=0',
+            'in_v_chr_pos=128',
+            'in_color_matrix=bt601',
+            'flags=' + '+'.join(vf_flags),
+        ))
+
+    else:
+        vf = ':'.join((
+            # Just in case the video is anamorphic
+            "scale='max(sar,1)*iw':'max(1/sar,1)*ih'",
+            # These flags seem to be universal
+            'flags=' + '+'.join(vf_flags),
+        ))
+
     return (
         _ffmpeg_executable(),
         '-y',
@@ -30,13 +76,13 @@ def _make_screenshot_cmd(video_file, timestamp, screenshot_file):
         '-loglevel', 'error',
         '-ss', str(timestamp),
         '-i', utils.video.make_ffmpeg_input(video_file),
+        '-vf', vf,
+        '-pix_fmt', 'rgb24',
         '-vframes', '1',
-        # Use correct aspect ratio
-        # https://ffmpeg.org/ffmpeg-filters.html#toc-Examples-99
-        '-vf', 'scale=trunc(ih*dar):ih,setsar=1/1',
         f'file:{screenshot_file}',
     )
 
+
 def screenshot(video_file, timestamp, screenshot_file, overwrite=False):
     """
     Create single screenshot from video file
@@ -210,3 +256,49 @@ def resize(image_file, width=0, height=0, target_directory=None, target_filename
         raise errors.ImageResizeError(f'Failed to resize: {error}')
     else:
         return str(target_filepath)
+
+
+# NOTE: Most of the optimization is achieved at level 1 with ~40 % smaller
+#       files. Anything higher seems to only reduce by tens of kB or less.
+_optimization_levels = {
+    'low': '1',
+    'medium': '2',
+    'high': '4',
+    'placebo': 'max',
+}
+
+optimization_levels = tuple(_optimization_levels) + ('none', 'default')
+"""Valid `level` arguments for :func:`optimize`"""
+
+
+def optimize(image_file, level=4):
+    """
+    Optimize PNG image size
+
+    `image_file` is overwritten with the smaller image data.
+
+    :path image_file: Path to PNG File
+
+    :path str,int level: Optimiziation level (``"low"``, ``"medium"``,
+        ``"high"``) or ``"default"`` to use recommended level or ``"none"`` /
+        `None` to not do any optimization
+    """
+    if level not in ('none', None):
+        if level == 'default':
+            level = 'medium'
+
+        try:
+            opt = _optimization_levels[str(level)]
+        except KeyError:
+            raise errors.ImageOptimizeError(f'Invalid optimization level: {level}')
+
+        cmd = [
+            'oxipng', '--quiet', '--preserve',
+            '--opt', opt,
+            '--interlace', '0',  # Remove any interlacing
+            '--strip', 'safe',   # Remove irrelevant metadata
+            str(image_file),
+        ]
+        error = utils.subproc.run(cmd, join_stderr=True)
+        if error:
+            raise errors.ImageOptimizeError(f'Failed to optimize: {error}')
