@@ -4,6 +4,8 @@ import difflib
 import os
 import re
 
+import async_lru
+
 from ... import constants, errors, utils
 from . import SceneCheckResult
 
@@ -97,6 +99,7 @@ class MultiPredbApi:
             else:
                 yield result
 
+    @async_lru.alru_cache
     async def search(self, *args, **kwargs):
         """
         Search multiple predbs concurrently and return first non-empty results
@@ -120,6 +123,7 @@ class MultiPredbApi:
             # No search results
             return []
 
+    @async_lru.alru_cache
     async def release_files(self, *args, **kwargs):
         """See :meth:`~.PredbApiBase.release_files`"""
         return await self._for_each_predb('release_files', *args, **kwargs)
@@ -130,6 +134,7 @@ class MultiPredbApi:
         re.compile(r'^(?i:nogrp)$'),
     )
 
+    @async_lru.alru_cache
     async def is_scene_release(self, release):
         """
         Return whether `release` is a scene release or not
@@ -137,8 +142,7 @@ class MultiPredbApi:
         .. note:: A renamed or otherwise altered scene release is still
             considered a scene release.
 
-        :param release: Release name, path to release or
-            :class:`~.release.ReleaseInfo` instance
+        :param release: Release name, path to release
 
         :return: :class:`~.types.SceneCheckResult`
         """
