@@ -29,7 +29,7 @@ class SrrdbApi(base.PredbApiBase):
         combined_results = []
         for skip in range(0, self._max_skip + 1, self._page_size):
             keywords_path = self._get_keywords_path(keywords, group, skip)
-            results = await self._request_page(keywords_path)
+            results = await self._request_search_page(keywords_path)
             combined_results.extend(results)
             if len(results) < self._page_size:
                 # We didn't get a full page, so we assume this is the last page
@@ -37,7 +37,7 @@ class SrrdbApi(base.PredbApiBase):
 
         return combined_results
 
-    async def _request_page(self, keywords_path):
+    async def _request_search_page(self, keywords_path):
         search_url = f'{self._search_url}/{keywords_path}'
         _log.debug('Search URL: %s', search_url)
         response = (await http.get(search_url, cache=True)).json()
