@@ -478,7 +478,39 @@ class ReleaseName(collections.abc.Mapping):
     @_translated_property
     def source(self):
         '''Original source (e.g. "BluRay", "WEB-DL") or "UNKNOWN_SOURCE"'''
-        return self._info.get('source') or 'UNKNOWN_SOURCE'
+        source = None
+
+        # DVD
+        video_ts_path = utils.fs.find_name('VIDEO_TS', self._path, validator=os.path.isdir)
+        if video_ts_path:
+            # Include VIDEO_TS siblings (e.g. "cover")
+            release_size = utils.fs.path_size(os.path.dirname(video_ts_path))
+            _log.debug('VIDEO_TS size: %r: %r', video_ts_path, release_size)
+            if release_size <= 4_700_000_000:
+                source = 'DVD5'
+            else:
+                source = 'DVD9'
+
+        if source is None:
+            # Blu-ray
+            bdmv_path = utils.fs.find_name('BDMV', self._path, validator=os.path.isdir)
+            if bdmv_path:
+                # Include BDMV siblings (e.g. "CERTIFICATE", and "ANY!")
+                release_size = utils.fs.path_size(os.path.dirname(bdmv_path))
+                _log.debug('Blu-ray size: %r: %r', bdmv_path, release_size)
+                if release_size <= 25e9:
+                    source = 'BD25'
+                elif release_size <= 50e9:
+                    source = 'BD50'
+                elif release_size <= 66e9:
+                    source = 'BD66'
+                else:
+                    source = 'BD100'
+
+        if source is None:
+            source = self._info.get('source') or 'UNKNOWN_SOURCE'
+
+        return source
 
     @source.setter
     def source(self, value):
@@ -503,13 +535,13 @@ class ReleaseName(collections.abc.Mapping):
     @_translated_property
     def audio_format(self):
         """
-        Audio format or "UNKNOWN_AUDIO_FORMAT"
+        Audio format (e.g. "FLAC") or empty string (no audio track)
 
         :raise ContentError: if path exists but contains unexpected data
         """
         af = video.audio_format(self._path, default=None)
         if af is None:
-            af = self._info.get('audio_codec') or 'UNKNOWN_AUDIO_FORMAT'
+            af = self._info.get('audio_codec') or ''
         return af
 
     @audio_format.setter
@@ -519,7 +551,7 @@ class ReleaseName(collections.abc.Mapping):
     @_translated_property
     def audio_channels(self):
         """
-        Audio channels (e.g. "5.1") or empty string
+        Audio channels (e.g. "5.1") or empty string (no audio track)
 
         :raise ContentError: if path exists but contains unexpected data
         """
@@ -671,14 +703,22 @@ class ReleaseName(collections.abc.Mapping):
             raise ValueError(f'Unknown HDR format: {value!r}')
 
     _needed_attrs = {
-        ReleaseType.movie: ('title', 'year', 'resolution', 'source',
-                            'audio_format', 'video_format'),
-        ReleaseType.season: ('title', 'episodes', 'resolution', 'source',
-                             'audio_format', 'video_format'),
-        ReleaseType.episode: ('title', 'episodes', 'resolution', 'source',
-                              'audio_format', 'video_format'),
+        ReleaseType.movie: ('title', 'year', 'resolution', 'source', 'video_format'),
+        ReleaseType.season: ('title', 'episodes', 'resolution', 'source', 'video_format'),
+        ReleaseType.episode: ('title', 'episodes', 'resolution', 'source', 'video_format'),
     }
 
+    @functools.cached_property
+    def dvd_encoding(self):
+        """"PAL", "NTSC" or `None`"""
+        if self.source in ('DVD', 'DVD5', 'DVD9', 'DVDRip'):
+            frame_rate = utils.video.frame_rate(self._path, default=0)
+            if frame_rate:
+                if frame_rate <= 25:
+                    return 'PAL'
+                elif frame_rate <= 30:
+                    return 'NTSC'
+
     @property
     def is_complete(self):
         """
@@ -826,7 +866,10 @@ class ReleaseName(collections.abc.Mapping):
         if self.type in (ReleaseType.season, ReleaseType.episode) and not self.date:
             parts.append(str(self.episodes))
 
-        parts.append(self.resolution)
+        if self.dvd_encoding:
+            parts.append(self.dvd_encoding)
+        else:
+            parts.append(self.resolution)
 
         if self.service:
             parts.append(self.service)
@@ -836,7 +879,9 @@ class ReleaseName(collections.abc.Mapping):
         if self.edition:
             parts.append(' '.join(self.edition))
 
-        parts.append(self.audio_format)
+        if self.audio_format:
+            parts.append(self.audio_format)
+
         if self.audio_channels:
             parts.append(self.audio_channels)
 
@@ -850,6 +895,8 @@ class ReleaseName(collections.abc.Mapping):
             joined = joined.replace(' ', sep)
 
         if sep == '.':
+            # Replace "&" with "and" before "&" gets removed
+            joined = re.sub(r'&', 'and', joined)
             # Remove non-word characters like (e.g.: ,:) with some exceptions
             joined = re.sub(r'[^ \w\.-]', '', joined)
             # Deduplicate "."
@@ -1407,7 +1454,8 @@ class Episodes(dict):
             {'': ('1', '2',), '3': ('6',)}
         """
         def extract_number(string):
-            return ''.join(c for c in string if c in '0123456789').lstrip('0')
+            n = ''.join(c for c in string if c in '0123456789').lstrip('0')
+            return '0' if n == '' else n
 
         def split_episodes(string):
             return {extract_number(e) for e in string.split('E') if e.strip()}
