@@ -23,9 +23,10 @@ torrent (see :func:`create`)
 """
 
 
-def create(*, content_path, announce, source, torrent_path,
-           use_cache=True, exclude=(), reuse_torrent_path=None,
-           piece_size_min=None, piece_size_max=None,
+def create(*, content_path, announce, source,
+           torrent_path, exclude=(), use_cache=True,
+           reuse_torrent_path=None, randomize_infohash=True,
+           piece_size_calculator=None, piece_size_min_max_calculator=None,
            init_callback, progress_callback):
     """
     Generate and write torrent file
@@ -36,13 +37,6 @@ def create(*, content_path, announce, source, torrent_path,
         the torrent unique for each tracker to avoid cross-seeding issues, so it
         is usually the tracker's abbreviated name.
     :param str torrent_path: Path of the generated torrent file
-    :param int piece_size_min: Minimum piece size
-    :param int piece_size_max: Maximum piece size
-    :param init_callback: Callable that is called once before torrent generation
-        commences with a :class:`Files` object
-    :param progress_callback: Callable that is called at regular intervals with
-        a :class:`CreateTorrentProgress` or :class:`FindTorrentProgress` object
-        as a positional argument
     :param exclude: Sequence of glob patterns (:class:`str`) and
         :class:`re.Pattern` objects (return value from :func:`re.compile`)
 
@@ -63,6 +57,24 @@ def create(*, content_path, announce, source, torrent_path,
 
         If this is a sequence, its items are expected to be directory or file
         paths and handled as described above.
+    :param randomize_infohash: Whether the torrent is made unique by randomizing
+        the infohash
+
+        This is done by including a random number in the torrent.
+    :param piece_size_calculator: Function that takes the torrent's content size
+        in bytes and returns the piece size
+
+        If this is `None`, the default implementation is used.
+    :param piece_size_min_max_calculator: Function that takes the torrent's
+        content size in bytes and returns the allowed minimum and maximum piece
+        sizes
+
+        If this is `None`, the default minimum and maximum piece sizes are used.
+    :param init_callback: Callable that is called once before torrent generation
+        commences with a :class:`Files` object
+    :param progress_callback: Callable that is called at regular intervals with
+        a :class:`CreateTorrentProgress` or :class:`FindTorrentProgress` object
+        as a positional argument
 
     Callbacks can cancel the torrent creation by returning `True` or any other
     truthy value. If `progress_callback` returns :data:`SKIP_SEARCHING`, the
@@ -83,9 +95,17 @@ def create(*, content_path, announce, source, torrent_path,
         exclude=_get_exclude_regexs(exclude),
         announce=announce,
         source=source,
-        piece_size_min=piece_size_min,
-        piece_size_max=piece_size_max,
+        randomize_infohash=randomize_infohash,
     )
+
+    # Custom piece_size management
+    if piece_size_min_max_calculator:
+        # Calculate custom piece_size boundaries based on torrent's content size
+        torrent.piece_size_min, torrent.piece_size_max = piece_size_min_max_calculator(torrent.size)
+    if piece_size_calculator:
+        # Calculate custom piece_size based on torrent's content size
+        torrent.piece_size = piece_size_calculator(torrent.size)
+
     # Report files with `exclude` applied
     cancelled = init_callback(Files(torrent))
     if cancelled:
@@ -131,15 +151,14 @@ def _get_exclude_regexs(exclude):
     return regexs
 
 
-def _get_torrent(*, content_path, exclude, announce, source, piece_size_min, piece_size_max):
+def _get_torrent(*, content_path, exclude, announce, source, randomize_infohash):
     try:
         return torf.Torrent(
             path=content_path,
             exclude_regexs=exclude,
-            piece_size_min=piece_size_min,
-            piece_size_max=piece_size_max,
             trackers=((announce,),),
             source=source,
+            randomize_infohash=randomize_infohash,
             private=True,
             created_by=f'{__project_name__} {__version__}',
             creation_date=time.time(),
@@ -162,6 +181,10 @@ def _generate_hashes(*, torrent, callback):
 
 
 def _find_hashes(*, torrent, reuse_torrent_path, callback):
+    if not torrent.files:
+        # All files are excluded (let someone deal with it)
+        return False
+
     wrapped_callback = _FindTorrentCallback(callback)
     try:
         torrent.reuse(
@@ -525,8 +548,7 @@ def filter_files(content_path, exclude=()):
             exclude=_get_exclude_regexs(exclude),
             announce='http://dummy.local',
             source=None,
-            piece_size_min=None,
-            piece_size_max=None,
+            randomize_infohash=False,
         )
     except errors.TorrentError as e:
         raise errors.ContentError(e)
