@@ -53,7 +53,7 @@ def mediainfo(path, only_first=True):
     :param str path: Path to video file or directory
     :param bool only_first: Whether to return mediainfo for each video file as a
         :class:`list` or to return mediainfo of the first video file (see
-        :func:`find_video`)
+        :func:`find_videos`)
 
     :raise ContentError: if anything goes wrong
     """
@@ -145,7 +145,19 @@ def tracks(path, default=NO_DEFAULT_VALUE):
     """
     if default is not NO_DEFAULT_VALUE and not os.path.exists(path):
         return default
-    return _tracks(find_videos(path)[0])
+
+    try:
+        main_videos = find_videos(path)
+    except errors.ContentError:
+        # No video file found - use path as is. This allows us to get tracks
+        # from an .IFO file, which isn't a video, so find_videos() raises
+        # ContentError. _tracks()/_run_mediainfo() will still raise ContentError
+        # if `path` mediainfo can't handle it.
+        video_filepath = path
+    else:
+        video_filepath = main_videos[0]
+
+    return _tracks(video_filepath)
 
 def _tracks(video_file_path):
     stdout = _run_mediainfo(video_file_path, '--Output=JSON')
@@ -171,10 +183,12 @@ def default_track(type, path, default=NO_DEFAULT_VALUE):
     :param str path: Path to video file or directory
 
         For directories, the first video is used. See :func:`find_videos`.
-    :param default: Return value if `path` doesn't exist, raise
-        :exc:`~.ContentError` if not provided
+    :param default: Return value if `path` doesn't exist or doesn't have a
+        `type` track
 
-    :raise ContentError: if anything goes wrong
+         If this is not provided, raise :exc:`~.ContentError`.
+
+    :raise ContentError: if anything goes wrong and `default` is not provided
     """
     if default is not NO_DEFAULT_VALUE and not os.path.exists(path):
         return default
@@ -195,7 +209,10 @@ def default_track(type, path, default=NO_DEFAULT_VALUE):
     except (KeyError, IndexError):
         pass
 
-    raise errors.ContentError(f'{path}: No {type.lower()} track found: {all_tracks!r}')
+    if default is NO_DEFAULT_VALUE:
+        raise errors.ContentError(f'{path}: No {type.lower()} track found: {all_tracks!r}')
+    else:
+        return default
 
 
 @functools.lru_cache(maxsize=None)
@@ -424,8 +441,7 @@ video track fields to regular expressions that must match the fields' values
 @functools.lru_cache(maxsize=None)
 def hdr_format(path, default=NO_DEFAULT_VALUE):
     """
-    Return HDR format based on `hdr_formats`, e.g. "HDR10", or empty string if
-    it can't be determined
+    Return HDR format based on `hdr_formats`, e.g. "HDR10", or empty string
 
     :param str path: Path to video file or directory
 
@@ -490,6 +506,63 @@ def has_dual_audio(path, default=NO_DEFAULT_VALUE):
         return False
 
 
+def is_bt601(path, default=NO_DEFAULT_VALUE):
+    """
+    Whether `path` is BT.601 (~SD) video
+
+    :param str path: Path to video file or directory
+
+        For directories, the first video is used. See :func:`find_videos`.
+    :param default: Return value if `path` doesn't exist, raise
+        :exc:`~.ContentError` if not provided
+
+    :raise ContentError: if reading `path` fails
+    """
+    if default is not NO_DEFAULT_VALUE and not os.path.exists(path):
+        return default
+
+    # https://rendezvois.github.io/video/screenshots/programs-choices/#color-matrix
+    if _get_color_matrix(path, 'BT.601'):
+        return True
+    elif _get_color_matrix(path, 'BT.470 System B/G'):
+        return True
+    else:
+        # Assume BT.601 if there is no HD video track
+        video_tracks = tracks(path).get('Video', ())
+        for video_track in video_tracks:
+            resolution = _get_closest_standard_resolution(video_track)
+            if resolution >= 720:
+                return False
+        return True
+
+def is_bt709(path, default=NO_DEFAULT_VALUE):
+    """
+    Whether `path` is BT.709 (~HD) video
+
+    See :func:`is_bt601`.
+    """
+    return _get_color_matrix(path, 'BT.709', default=default)
+
+def is_bt2020(path, default=NO_DEFAULT_VALUE):
+    """
+    Whether `path` is BT.2020 (~UHD) video
+
+    See :func:`is_bt601`.
+    """
+    return _get_color_matrix(path, 'BT.2020', default=default)
+
+def _get_color_matrix(path, name, default=NO_DEFAULT_VALUE):
+    if default is not NO_DEFAULT_VALUE and not os.path.exists(path):
+        return default
+
+    # https://rendezvois.github.io/video/screenshots/programs-choices/#color-matrix
+    video_tracks = tracks(path).get('Video', ())
+    for video_track in video_tracks:
+        if video_track.get('matrix_coefficients', '').startswith(name):
+            return True
+    return False
+
+
 @functools.lru_cache(maxsize=None)
 def has_commentary(path, default=NO_DEFAULT_VALUE):
     """
@@ -549,14 +622,22 @@ def audio_format(path, default=NO_DEFAULT_VALUE):
     :param str path: Path to video file or directory
 
         For directories, the first video is used. See :func:`find_videos`.
-    :param default: Return value if `path` doesn't exist, raise
-        :exc:`~.ContentError` if not provided
+    :param default: Return value if `path` doesn't exist or has no audio track,
+        raise :exc:`~.ContentError` if not provided
 
-    :raise ContentError: if no audio track is found
+    :raise ContentError: if no audio track is found and no `default` is provided
     """
     if default is not NO_DEFAULT_VALUE and not os.path.exists(path):
         return default
 
+    try:
+        audio_track = default_track('audio', path)
+    except errors.ContentError:
+        if default is NO_DEFAULT_VALUE:
+            raise
+        else:
+            audio_track = {}
+
     def is_match(regexs, audio_track):
         for key,regex in regexs.items():
             if regex is None:
@@ -574,13 +655,10 @@ def audio_format(path, default=NO_DEFAULT_VALUE):
         # All `regexs` match and no forbidden keys exist in `audio_track`
         return True
 
-    audio_track = default_track('audio', path)
-    _log.debug('Audio track for %r: %r', path, audio_track)
     parts = []
-    for fmt,regexs in _audio_format_translations:
+    for fmt, regexs in _audio_format_translations:
         if fmt not in parts and is_match(regexs, audio_track):
             parts.append(fmt)
-
     return ' '.join(parts)
 
 
@@ -606,23 +684,29 @@ def audio_channels(path, default=NO_DEFAULT_VALUE):
     :param str path: Path to video file or directory
 
         For directories, the first video is used. See :func:`find_videos`.
-    :param default: Return value if `path` doesn't exist, raise
-        :exc:`~.ContentError` if not provided
+    :param default: Return value if `path` doesn't exist or has no audio track,
+        raise :exc:`~.ContentError` if not provided
 
-    :raise ContentError: if no audio track is found
+    :raise ContentError: if no audio track is found and no `default` is provided
     """
     if default is not NO_DEFAULT_VALUE and not os.path.exists(path):
         return default
 
+    try:
+        audio_track = default_track('audio', path)
+    except errors.ContentError:
+        if default is NO_DEFAULT_VALUE:
+            raise
+        else:
+            audio_track = {}
+
     audio_channels = ''
-    audio_track = default_track('audio', path)
     channels = audio_track.get('Channels', '')
-    if channels:
-        for achan,regex in _audio_channels_translations:
-            if regex.search(channels):
-                audio_channels = achan
-                break
-    _log.debug('Detected audio channels: %s', audio_channels)
+    for achan,regex in _audio_channels_translations:
+        if regex.search(channels):
+            audio_channels = achan
+            break
+
     return audio_channels
 
 
@@ -799,7 +883,7 @@ def _filter_main_videos_dvd(video_file_paths):
     # Group files by common VIDEO_TS parent directory
     for video_file_path in video_file_paths:
         match = re.search(
-            rf'^(.*{os.sep}VIDEO_TS)({os.sep}VTS_\d+_\d+.[A-Z]+)$',
+            rf'^(.*{utils.fs.OS_SEP_REGEX}VIDEO_TS)({utils.fs.OS_SEP_REGEX}VTS_\d+_\d+.[A-Z]+)$',
             video_file_path,
         )
         if match:
@@ -830,7 +914,7 @@ def find_main_vobs(video_ts_files):
     """
     all_vobs = (
         filepath for filepath in video_ts_files
-        if re.search(rf'{os.sep}VIDEO_TS{os.sep}VTS_\d+_\d+\.VOB$', filepath)
+        if re.search(rf'{utils.fs.OS_SEP_REGEX}VIDEO_TS{utils.fs.OS_SEP_REGEX}VTS_\d+_\d+\.VOB$', filepath)
     )
     vob_sets = collections.defaultdict(lambda: [])
     for vob_path in all_vobs:
@@ -911,7 +995,7 @@ def for_each_video_ts(path):
     """
     video_ts_paths = natsort.natsorted(
         glob.glob(
-            f'{path}{os.sep}**{os.sep}VIDEO_TS',
+            f'{path}{utils.fs.OS_SEP_REGEX}**{utils.fs.OS_SEP_REGEX}VIDEO_TS',
             recursive=True,
         )
     )
