@@ -57,15 +57,24 @@ class WebDbApiBase(abc.ABC):
 
     def sanitize_query(self, query):
         """
-        Modify :class:`~.common.Query` for specific DB
+        Modify :class:`.Query` for specific DB
 
-        See :meth:`.TvmazeApi.sanitize_query` for an example.
+        If :meth:`get_id_from_text` finds an ID in :attr:`.Query.title`,
+        :attr:`.Query.id` is set to that ID, which means all other query
+        parameters are ignored.
         """
         if not isinstance(query, Query):
             raise TypeError(f'Not a Query instance: {query!r}')
         else:
+            id_from_url = self.get_id_from_text(query.title)
+            if id_from_url:
+                query.id = id_from_url
             return query
 
+    @abc.abstractmethod
+    def get_id_from_text(self, text):
+        """Return ID found in `text` or `None`"""
+
     @abc.abstractmethod
     async def search(self, query):
         """
