@@ -27,15 +27,18 @@ class ImdbApi(WebDbApiBase):
 
     async def _get_soup(self, path, params={}):
         path = path.rstrip('/')
+
         cache_id = (path, tuple(sorted(params.items())))
         if cache_id in self._soup_cache:
             return self._soup_cache[cache_id]
+
         text = await utils.http.get(
-            url=f'{self._url_base}/{path}',
+            url=f'{self._url_base}/{path}/',
             params=params,
             user_agent=await utils.http.get_popular_user_agent(),
             cache=True,
         )
+
         self._soup_cache[cache_id] = utils.html.parse(text)
         return self._soup_cache[cache_id]
 
@@ -64,6 +67,12 @@ class ImdbApi(WebDbApiBase):
         query.title = re.sub(r'\b(?i:wont)(\b)', "won't", query.title)
         return query
 
+    def get_id_from_text(self, text):
+        # Example: https://www.imdb.com/title/tt0048918/
+        match = re.search(r'\b(tt\d+)\b', text)
+        if match:
+            return match.group(1)
+
     async def search(self, query):
         _log.debug('Searching IMDb for %s', query)
 
@@ -202,7 +211,7 @@ class ImdbApi(WebDbApiBase):
                 if url:
                     if '@' in url:
                         # Remove any cropping instructions and other stuff
-                        url = re.sub(r'@.*(\.\w+)$', r'@\1', url)
+                        url = re.sub(r'_CR[\d+,]+', r'', url)
                     return url
 
         return ''
@@ -362,10 +371,11 @@ class ImdbApi(WebDbApiBase):
             soup = await self._get_soup(f'title/{id}/reference')
 
             tag = soup.find(class_='titlereference-title-year')
-            text = ' '.join(reversed(tuple(tag.stripped_strings))).lower()
-            match = re.search(r'\b(\d{4})\b', text)
-            if match:
-                return match.group(1)
+            if tag:
+                text = ' '.join(reversed(tuple(tag.stripped_strings))).lower()
+                match = re.search(r'\b(\d{4})\b', text)
+                if match:
+                    return match.group(1)
 
         return ''
 
