@@ -38,6 +38,14 @@ class TmdbApi(WebDbApiBase):
         self._soup_cache[cache_id] = html.parse(text)
         return self._soup_cache[cache_id]
 
+    def get_id_from_text(self, text):
+        # Examples:
+        # https://www.themoviedb.org/movie/334536-the-blackcoat-s-daughter
+        # https://www.themoviedb.org/tv/45016-bron-broen
+        match = re.search(r'\b((?i:movie|tv)/\d+)\b', text)
+        if match:
+            return match.group(1)
+
     async def search(self, query):
         _log.debug('Searching TMDb for %s', query)
 
