@@ -5,6 +5,7 @@ API for tvmaze.com
 import collections
 import functools
 import json
+import re
 
 from ... import errors, utils
 from .. import html, http
@@ -32,6 +33,12 @@ class TvmazeApi(WebDbApiBase):
         query.type = ReleaseType.unknown
         return query
 
+    def get_id_from_text(self, text):
+        # Example: https://www.tvmaze.com/shows/36906/gary-and-his-demons
+        match = re.search(r'\b(?i:shows)/(\d+)\b', text)
+        if match:
+            return match.group(1)
+
     async def search(self, query):
         _log.debug('Searching TVmaze for %s', query)
 
